==> httpmaid-jsr356-0.9.112-sources.jar: de/quantummaid/httpmaid/jsr356/HandshakeMetaData.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.jsr356;

import de.quantummaid.httpmaid.http.Headers;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import java.util.Map;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor
public final class HandshakeMetaData {
    private Headers headers;
    private Map<String, Object> additionalWebsocketData;

    public static HandshakeMetaData handshakeMetaData() {
        return new HandshakeMetaData();
    }

    public synchronized void setHeaders(final Headers headers) {
        this.headers = headers;
    }

    public synchronized Headers getHeaders() {
        return headers;
    }

    public void setAdditionalWebsocketData(final Map<String, Object> additionalWebsocketData) {
        this.additionalWebsocketData = additionalWebsocketData;
    }

    public Map<String, Object> getAdditionalWebsocketData() {
        return additionalWebsocketData;
    }
}

==> httpmaid-jsr356-0.9.137-sources.jar: de/quantummaid/httpmaid/jsr356/HandshakeMetaData.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.jsr356;

import de.quantummaid.httpmaid.websockets.registry.WebsocketRegistryEntry;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor
public final class HandshakeMetaData {
    private WebsocketRegistryEntry websocketRegistryEntry;

    public static HandshakeMetaData handshakeMetaData() {
        return new HandshakeMetaData();
    }

    public synchronized void setWebsocketRegistryEntry(final WebsocketRegistryEntry websocketRegistryEntry) {
        this.websocketRegistryEntry = websocketRegistryEntry;
    }

    public synchronized WebsocketRegistryEntry getWebsocketRegistryEntry() {
        return websocketRegistryEntry;
    }
}
